@@ -1,4 +1,4 @@
-from config import global_config
+from maitai.config import global_config
 from maitai import Loadable
 
 
